@@ -6,11 +6,16 @@
 #' @return a list with the parameters of the virtual track
 #'
 #' @examples
-#' emr_vtrack.create("a")
-#' .emr_vtrack.get("vt")
+#' emr_db.init_examples()
 #'
+#' emr_vtrack.create("vtrack1", "dense_track",
+#'     time.shift = 1,
+#'     func = "max"
+#' )
+#' .emr_vtrack.get("vtrack1")
+#'
+#' @keywords internal
 #' @export
-#' @noRd
 .emr_vtrack.get <- function(vtrackstr, adjust_logical = TRUE) {
     if (!emr_vtrack.exists(vtrackstr)) {
         stop(sprintf("Virtual track %s does not exist", vtrackstr), call. = FALSE)
@@ -72,6 +77,156 @@
     return(params)
 }
 
+#' Generate a default name for a virtual track
+#'
+#' Given virtual track parameters, generate a name with the following format:
+#' "vt_{src}.func_{func}.params_{params}.kr{keepref}.ts_{time.shift}.id_{id.map}.filter_{filter}"
+#' Where for 'params', 'time.shift', and 'id.map', the values are separated by an
+#' underscore.
+#'
+#' If \code{func}, \code{params}, \code{time.shift}, \code{id.map}, or \code{filter} are
+#' \code{NULL} - their section would not appear in the generated name.
+#'
+#' @param src a character vector specifying the source dataset(s) or filter(s) that the virtual track is based on
+#' @param func a character vector specifying the function(s) applied to the source data to generate the virtual track
+#' @param params a named list specifying the parameters used by the function(s) to generate the virtual track
+#' @param keepref a logical value indicating whether the virtual track should keep the reference column(s) of the source data
+#' @param time.shift a numeric vector specifying the time shift(s) applied to the virtual track
+#' @param id.map a named list specifying the mapping of the IDs between the source data and the virtual track
+#' @param filter a character vector specifying the filter(s) applied to the virtual track. Note that the filter name cannot contain the character '.'
+#'
+#' @return a default name for the virtual track
+#'
+#' @seealso \code{\link{emr_vtrack.create}}
+#' @keywords ~virtual track
+#'
+#' @examples
+#'
+#' emr_db.init_examples()
+#' emr_vtrack.name("dense_track",
+#'     time.shift = 1,
+#'     func = "max"
+#' )
+#'
+#' @export
+emr_vtrack.name <- function(src, func = NULL, params = NULL, keepref = FALSE, time.shift = NULL, id.map = NULL, filter = NULL) {
+    if (missing(src)) {
+        stop("Usage: emr_vtrack.name(src, func = NULL, params = NULL, keepref = FALSE, time.shift = NULL, id.map = NULL, filter = NULL)", call. = FALSE)
+    }
+
+    if (!is.character(src)) {
+        stop("Cannot generate automatic virtual track name when source is not a character vector", call. = FALSE)
+    }
+
+    if (!is.null(id.map)) {
+        stop("Cannot generate automatic virtual track name when id.map is not NULL", call. = FALSE)
+    }
+
+    src_str <- get_src_str(src)
+    func_str <- get_func_str(func)
+    params_str <- get_params_str(params)
+    keepref_str <- get_keepref_str(keepref)
+    time_shift_str <- get_time_shift_str(time.shift)
+    if (any(grepl("\\.", filter))) {
+        stop("Cannot generate automatic virtual track name when filter contains '.'", call. = FALSE)
+    }
+
+    filter_str <- get_filter_str(filter)
+
+    vtrack_name <- glue::glue("vt_{src_str}{func_str}{params_str}{keepref_str}{time_shift_str}{filter_str}")
+
+    vtrack_name <- gsub("-", "minus", vtrack_name)
+    vtrack_name <- gsub("\\.$", "", vtrack_name)
+
+    return(as.character(vtrack_name))
+}
+
+#' Create a virtual track from an automatically generated name
+#'
+#' @param vtrack_name name of a virtual track automatically generated by \code{emr_vtrack.name}. Can be a vector of virtual track names.
+#'
+#' @seealso \code{\link{emr_vtrack.create}}, \code{\link{emr_vtrack.name}}
+#' @keywords ~virtual track
+#'
+#' @return an \code{emr_vtrack} object
+#'
+#' @examples
+#'
+#' emr_db.init_examples()
+#' emr_filter.create("f_dense_track", "dense_track", time.shift = c(2, 4))
+#'
+#' name <- emr_vtrack.name("dense_track",
+#'     time.shift = 1,
+#'     func = "max",
+#'     filter = "f_dense_track"
+#' )
+#'
+#' emr_vtrack.create_from_name(name)
+#' @export
+emr_vtrack.create_from_name <- function(vtrack_name) {
+    if (missing(vtrack_name)) {
+        stop("Usage: emr_vtrack.create_from_name(vtrack_name)", call. = FALSE)
+    }
+
+    if (length(vtrack_name) > 1) {
+        return(purrr::map(emr_vtrack.create_from_name, vtrack_name))
+    }
+
+    # src
+    parsed_str <- stringr::str_match(vtrack_name, "vt_(.+)\\.func_")
+    src_str <- parsed_str[, 2]
+
+    # func
+    parsed_str <- stringr::str_match(vtrack_name, "\\bfunc_(.+)\\.params_")
+    func_str <- parsed_str[, 2]
+    if (is.na(func_str)) {
+        func_str <- NULL
+    }
+
+    # params
+    parsed_str <- stringr::str_match(vtrack_name, "\\bparams_(.+?)\\.kr")
+    parsed_str[, 2] <- gsub("\\..+", "", parsed_str[, 2])
+    if (is.na(parsed_str[, 2])) {
+        params_list <- NULL
+    } else {
+        parsed_params_str <- parsed_str[, 2]
+        params_list <- emr_vtrack.parse_params(parsed_params_str)
+    }
+
+    # keepref
+    parsed_str <- stringr::str_match(vtrack_name, "\\.kr([TF])")
+    keepref <- as.logical(parsed_str[, 2])
+    if (is.na(keepref)) {
+        stop("Couldn't find keepref. Did you create the name using emr_vtrack.name?", call. = FALSE)
+    }
+
+    # time shift
+    parsed_str <- stringr::str_match(vtrack_name, "\\.ts_(.+)")
+    parsed_str[, 2] <- gsub("\\..+", "", parsed_str[, 2])
+    if (is.na(parsed_str[, 2])) {
+        time_shift <- NULL
+    } else {
+        parsed_str <- parsed_str[, 2]
+        time_shift <- stringr::str_split(parsed_str, "_")[[1]]
+        time_shift <- gsub("minus", "-", time_shift)
+        time_shift <- as.numeric(time_shift)
+        if (any(is.na(time_shift))) {
+            stop("Couldn't parse time.shift. Did you create the name using emr_track.name?", call. = FALSE)
+        }
+    }
+
+    # filter
+    parsed_str <- stringr::str_match(vtrack_name, "\\.filter_(.*)")
+    parsed_str[, 2] <- gsub("\\..+", "", parsed_str[, 2])
+    if (is.na(parsed_str[, 2])) {
+        filter <- NULL
+    } else {
+        filter <- parsed_str[, 2]
+        filter <- varname_to_logical(filter)
+    }
+
+    emr_vtrack.create(vtrack_name, src = src_str, func = func_str, params = params_list, keepref = keepref, time.shift = time_shift, id.map = NULL, filter = filter)
+}
 
 
 #' Creates a new virtual track
@@ -183,7 +338,7 @@
 #' 'keepref' is 'TRUE' only 'avg', 'percentile.upper' and 'percentile.lower'
 #' can be used in 'func'.
 #'
-#' @param vtrack virtual track name.
+#' @param vtrack virtual track name. If 'NULL' is used, a unique name is generated.
 #' @param src data source. either a track name or a list of two members: ID-Time Values table (see "User
 #' Manual") and a logical. If the logical is 'TRUE', the data in the table is treated as categorical, otherwise as quantitative.
 #' @param func,params see below.
@@ -221,6 +376,10 @@ emr_vtrack.create <- function(vtrack, src, func = NULL, params = NULL, keepref =
     }
     .emr_checkroot()
 
+    if (is.null(vtrack)) {
+        vtrack <- emr_vtrack.name(src = src, func = func, params = params, keepref = keepref, time.shift = time.shift, id.map = id.map, filter = filter)
+    }
+
     if (vtrack != make.names(vtrack)) {
         stop(sprintf("\"%s\" is not a syntactically valid name for a variable", vtrack), call. = FALSE)
     }
